@@ -472,21 +472,6 @@ impl Visit for UsageAnalyzer<'_> {
         })
     }
 
-    fn visit_constructor(&mut self, c: &Constructor) {
-        self.visit_with_scope(c.span.ctxt, ScopeKind::Fn, |v| {
-            v.is_pat_decl = true;
-            c.params.visit_with(v);
-            v.is_pat_decl = false;
-
-            match c.body.as_ref() {
-                Some(body) => {
-                    body.visit_children_with(v);
-                }
-                None => {}
-            }
-        })
-    }
-
     fn visit_class_method(&mut self, m: &ClassMethod) {
         m.function.decorators.visit_with(self);
 
@@ -504,6 +489,21 @@ impl Visit for UsageAnalyzer<'_> {
         })
     }
 
+    fn visit_constructor(&mut self, c: &Constructor) {
+        self.visit_with_scope(c.span.ctxt, ScopeKind::Fn, |v| {
+            v.is_pat_decl = true;
+            c.params.visit_with(v);
+            v.is_pat_decl = false;
+
+            match c.body.as_ref() {
+                Some(body) => {
+                    body.visit_children_with(v);
+                }
+                None => {}
+            }
+        })
+    }
+
     fn visit_export_default_specifier(&mut self, n: &ExportDefaultSpecifier) {
         self.add_usage(n.exported.to_id());
     }
@@ -610,6 +610,14 @@ impl Visit for UsageAnalyzer<'_> {
         self.visit_stmt_likes(stmts);
     }
 
+    fn visit_named_export(&mut self, n: &NamedExport) {
+        if n.src.is_some() {
+            return;
+        }
+
+        n.visit_children_with(self);
+    }
+
     fn visit_param(&mut self, p: &Param) {
         p.decorators.visit_with(self);
 
